You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficserver.apache.org by ma...@apache.org on 2019/06/17 23:42:17 UTC

[trafficserver] branch master updated: HTTP/2: increment write_vio.ndone by consumed size

This is an automated email from the ASF dual-hosted git repository.

masaori pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/trafficserver.git


The following commit(s) were added to refs/heads/master by this push:
     new d3639e0  HTTP/2: increment write_vio.ndone by consumed size
d3639e0 is described below

commit d3639e0f98d319f77a6fbd4ced5465578d64ad87
Author: Masaori Koshiba <ma...@apache.org>
AuthorDate: Fri Jun 14 09:23:26 2019 +0900

    HTTP/2: increment write_vio.ndone by consumed size
---
 proxy/http2/Http2Stream.cc | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/proxy/http2/Http2Stream.cc b/proxy/http2/Http2Stream.cc
index 24331d6..51b3759 100644
--- a/proxy/http2/Http2Stream.cc
+++ b/proxy/http2/Http2Stream.cc
@@ -590,8 +590,8 @@ Http2Stream::update_write_request(IOBufferReader *buf_reader, int64_t write_len,
     // Still parsing the response_header
     int bytes_used = 0;
     int state      = this->response_header.parse_resp(&http_parser, this->response_reader, &bytes_used, false);
-    // HTTPHdr::parse_resp() consumed the response_reader in above
-    write_vio.ndone += this->response_header.length_get();
+    // HTTPHdr::parse_resp() consumed the response_reader in above (consumed size is `bytes_used`)
+    write_vio.ndone += bytes_used;
 
     switch (state) {
     case PARSE_RESULT_DONE: {